@@ -1,5 +1,5 @@
 package Thrift::API::HiveClient2;
-$Thrift::API::HiveClient2::VERSION = '0.020';
+$Thrift::API::HiveClient2::VERSION = '0.021';
 {
   $Thrift::API::HiveClient2::DIST = 'Thrift-API-HiveClient2';
 }
@@ -23,27 +23,29 @@ use Thrift::BufferedTransport;
 # bug reports, will need to poke them directly.
 # see https://rt.cpan.org/Public/Bug/Display.html?id=86679
 
-package Thrift::TException;
-$Thrift::TException::VERSION = '0.020';
-{
-  $Thrift::TException::DIST = 'Thrift-API-HiveClient2';
-}
-use version;
+# update: not indexable by cpan as it injects code in another class which is
+# not ours. plus the version check doesn't work either because of a missing
+# package declaration in the Thrift class file, see:
+# https://issues.apache.org/jira/browse/THRIFT-3551
+# https://issues.apache.org/jira/browse/THRIFT-3549 
 
-my $thrift_version = version->parse($Thrift::VERSION);
-if ( $thrift_version >= version->parse('0.7.0') && $thrift_version <= version->parse('0.9.0') )
-{
-    eval <<'OVERLOAD';    #<<<
-    use overload '""' => sub {
-        return
-            ref( $_[0] )
-            . " error: "
-            . ( $_[0]->{message} || 'empty message' )
-            . " (code "
-            . ( defined $_[0]->{code} ? $_[0]->{code} : 'undefined' ) . ")";
-    };
-OVERLOAD
-}
+#package Thrift::TException;
+#use version;
+#
+#my $thrift_version = version->parse($Thrift::VERSION);
+#if ( $thrift_version >= version->parse('0.7.0') && $thrift_version <= version->parse('0.9.3') )
+#{
+#    eval <<'OVERLOAD';    #<<<
+#    use overload '""' => sub {
+#        return
+#            ref( $_[0] )
+#            . " error: "
+#            . ( $_[0]->{message} || 'empty message' )
+#            . " (code "
+#            . ( defined $_[0]->{code} ? $_[0]->{code} : 'undefined' ) . ")";
+#    };
+#OVERLOAD
+#}
 
 #>>>
 
@@ -527,7 +529,7 @@ Thrift::API::HiveClient2 - Perl to HiveServer2 Thrift API wrapper
 
 =head1 VERSION
 
-version 0.020
+version 0.021
 
 =head1 METHODS
 
@@ -629,7 +631,7 @@ disabled on HiveServer2 by setting this property in your
     </property>
 
 Starting with 0.014, support for secure clusters has been added thanks to
-Thrift::SASL::Transport. This behaviour is set by passing sasl => 1 to the
+L<Thrift::SASL::Transport>. This behaviour is set by passing sasl => 1 to the
 constructor. It has been tested with hive.server2.authentication = KERBEROS.
 It of course requires a valid credentials cache (kinit) or keytab.
 
@@ -666,6 +668,8 @@ L<https://github.com/dmorel/Thrift-API-HiveClient2>
 
 Burak Gürsoy (BURAK)
 
+Neil Bowers (NEILB)
+
 =head1 AUTHOR
 
 David Morel <david.morel@amakuru.net>
